@@ -38,6 +38,7 @@ class Revert(BaseSubcommand):
             )
 
         # Add common options
+        self.command_args(parser, 'revert')
         self.dry_run(parser)
 
         # Save the entry point for running this command.
@@ -61,7 +62,10 @@ class Revert(BaseSubcommand):
         checkouts = Checkouts(args.path, verbose=args.verbose)
 
         # Perform an svn update command against all checkouts.
-        command = 'svn revert %s'
+        command = ['svn', 'revert']
+        if len(args.command_args) > 0:
+            command.extend(self.split_command_line_args(args.command_args))
+        command.append('.')
         checkouts.perform(command, dry_run=args.dry_run)
 
         return
