@@ -14,6 +14,7 @@ import re
 import shutil
 import socket
 import StringIO
+import subprocess
 import sys
 import urllib2
 
@@ -232,7 +233,7 @@ class ProjectSet(object):
                 if not dry_run:
                     version = info['version']
                     target_dir = os.path.join(dir, "%s_%s" % (name, version))
-                    errcode = os.system('svn co "%s" "%s"' % (url, target_dir))
+                    errcode = subprocess.call(['svn', 'co', url, target_dir])
                     if errcode != 0:
                         break
 
